
import { Toaster } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { HelmetProvider } from 'react-helmet-async';
import { Suspense, lazy } from "react";
import Index from "./pages/Index";
import { ApiKeyProvider } from "./contexts/ApiKeyContext";
import { usePerformanceOptimization } from "./hooks/usePerformanceOptimization";

// Lazy loading per le pagine non critiche
const ChiSono = lazy(() => import("./pages/ChiSono"));
const Blog = lazy(() => import("./pages/Blog"));
const BlogPost = lazy(() => import("./pages/BlogPost"));
const Newsletter = lazy(() => import("./pages/Newsletter"));
const Admin = lazy(() => import("./pages/Admin"));
const AdminBlog = lazy(() => import("./pages/AdminBlog"));
const AdminArticles = lazy(() => import("./pages/AdminArticles"));
const NotFound = lazy(() => import("./pages/NotFound"));

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000, // 5 minuti
      gcTime: 10 * 60 * 1000, // 10 minuti (gcTime instead of cacheTime)
    },
  },
});

function App() {
  usePerformanceOptimization();

  return (
    <QueryClientProvider client={queryClient}>
      <HelmetProvider>
        <ApiKeyProvider>
          <TooltipProvider>
            <Toaster />
            <BrowserRouter>
              <Suspense fallback={
                <div className="min-h-screen flex items-center justify-center">
                  <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-porpora"></div>
                </div>
              }>
                <Routes>
                  <Route path="/" element={<Index />} />
                  <Route path="/chi-sono" element={<ChiSono />} />
                  <Route path="/blog" element={<Blog />} />
                  <Route path="/blog/:slug" element={<BlogPost />} />
                  <Route path="/newsletter" element={<Newsletter />} />
                  <Route path="/admin" element={<Admin />} />
                  <Route path="/admin/blog" element={<AdminBlog />} />
                  <Route path="/admin/articles" element={<AdminArticles />} />
                  <Route path="*" element={<NotFound />} />
                </Routes>
              </Suspense>
            </BrowserRouter>
          </TooltipProvider>
        </ApiKeyProvider>
      </HelmetProvider>
    </QueryClientProvider>
  );
}

export default App;
